==> piwigo-2.1.5.zip: piwigo/plugins/c13y_upgrade/language/vi_VN/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based picture gallery                                  |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2010 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

// --------- Starting below: New or revised $lang ---- from Butterfly (1.8)
$lang['c13y_upgrade_no_anomaly'] = 'Không có sự bất thường nào được phát hiện sau khi nâng cấp ứng dụng, plugin "Dò tìm bản nâng cấp" đã được tắt.';
$lang['c13y_dbl_email_user'] = 'Người dùng có cùng địa chỉ email';
$lang['c13y_correction_dbl_email_user'] = 'Xóa các người dùng có trùng tên';
$lang['c13y_obsolete_plugin'] = 'Plugin lỗi thời';
$lang['c13y_correction_obsolete_plugin'] = '"%s" plugin đã được kèm theo trong phiên bản của ứng dụng này và bạn bắt buộc phải gỡ bỏ nó ra.';

?>

==> piwigo-2.2.3.zip: piwigo/plugins/c13y_upgrade/language/vi_VN/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2011 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

// --------- Starting below: New or revised $lang ---- from Butterfly (1.8)
$lang['c13y_upgrade_no_anomaly'] = 'Không có sự bất thường nào được phát hiện sau khi nâng cấp ứng dụng, plugin "Dò tìm bản nâng cấp" đã được tắt.';
$lang['c13y_dbl_email_user'] = 'Người dùng có cùng địa chỉ email';
$lang['c13y_correction_dbl_email_user'] = 'Xóa các người dùng có trùng tên';
$lang['c13y_obsolete_plugin'] = 'Plugin lỗi thời';
$lang['c13y_correction_obsolete_plugin'] = '"%s" plugin đã được kèm theo trong phiên bản của ứng dụng này và bạn bắt buộc phải gỡ bỏ nó ra.';

?>
